@@ -1,8 +1,11 @@
-from bs4 import BeautifulSoup
-from symbol_helper import *
 import pprint
 import sys
 
+from bs4 import BeautifulSoup
+
+from finsymbols.symbol_helper import *
+
+
 def get_sp500_symbols():
 	page_html = wiki_html('List_of_S%26P_500_companies','SP500.html')
 	wiki_soup = BeautifulSoup(page_html)
@@ -11,41 +14,48 @@ def get_sp500_symbols():
 	symbol_data_list = list()
 
 	for symbol in symbol_table.find_all("tr"):
-		symbol_data_content = dict()	
+		symbol_data_content = dict()
 		symbol_raw_data = symbol.find_all("td")
 		td_count = 0
 		for symbol_data in symbol_raw_data:
-			if(td_count == 0): 
+			if(td_count == 0):
 				symbol_data_content['symbol'] = symbol_data.text.encode('utf-8')
-			elif(td_count == 1): 
+			elif(td_count == 1):
 				symbol_data_content['company'] = symbol_data.text.encode('utf-8')
-			elif(td_count == 3): 
+			elif(td_count == 3):
 				symbol_data_content['sector'] = symbol_data.text.encode('utf-8')
-			elif(td_count == 4): 
+			elif(td_count == 4):
 				symbol_data_content['industry'] = symbol_data.text.encode('utf-8')
 			elif(td_count == 5):
 				symbol_data_content['headquaters'] = symbol_data.text.encode('utf-8')
-			
+
 			td_count += 1
-				
+
 		symbol_data_list.append(symbol_data_content)
 
 	return symbol_data_list[1::]
 
+
 def get_nyse_symbols():
-	symbol_list = read_csv('NYSE')
-	return symbol_list
+    return _get_exchange_data("NYSE")
+
 
 def get_amex_symbols():
-	symbol_list = read_csv('AMEX')
-	return symbol_list
+    return _get_exchange_data("AMEX")
+
 
 def get_nasdaq_symbols():
-	symbol_list = read_csv('NASDAQ')
-	return symbol_list
+    return _get_exchange_data("NASDAQ")
 
-#if __name__ == "__main__":
-	#pprint.pprint(get_sp500_symbols())
-	#pprint.pprint(get_nyse_symbols())
-	#pprint.pprint(get_nasdaq_symbols())
-	#pprint.pprint(get_amex_symbols())
+
+def _get_exchange_data(exchange):
+    url = get_exchange_url(exchange)
+    file_path = os.path.join(os.path.dirname(finsymbols.__file__), exchange)
+    if is_cached(file_path):
+        with open(file_path, "r") as cached_file:
+            symbol_data = cached_file.read()
+    else:
+      symbol_data = fetch_file(url)
+      save_file(file_path,symbol_data)
+    
+    return get_symbol_list(symbol_data,exchange)
